@@ -4,7 +4,7 @@
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
 #
-#     http://www.apache.org/licenses/LICENSE-2.0
+# http://www.apache.org/licenses/LICENSE-2.0
 #
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
@@ -45,11 +45,12 @@ SET_CREDENTIAL_PROCESS_DEFAULT = True
 @click.argument("profile", metavar="PROFILE_NAME")
 @click.option("--sso-start-url", "-u", metavar="URL", help="Your AWS SSO start URL")
 @click.option("--sso-region", metavar="REGION", help="The AWS region your AWS SSO instance is deployed in")
-@click.option("--account-id", "-a", "account", metavar="ACCOUNT", help="The AWS account for the profile")
-@click.option("--role-name", "-r", "role", metavar="ROLE", help="The SSO role (also the Permission Set name) to assume in account")
+@click.option("--account-id", "-a", "account", metavar="ACCOUNT_ID", help="The AWS account for the profile")
+@click.option("--account", "account", hidden=True)
+@click.option("--role-name", "-r", "role", metavar="ROLE_NAME", help="The SSO role (also the Permission Set name) to assume in account")
 @click.option("--region", metavar="REGION", help="The AWS region the profile will use")
 @click.option("--output", "-o", metavar="CLI_OUTPUT_FORMAT", help="Set the CLI output format for the profile")
-@click.option("--config-default", "-c", multiple=True, metavar="KEY=VALUE", help="Additional config field to set, can provide multiple times")
+@click.option("--config-default", "-c", metavar="KEY=VALUE", multiple=True, help="Additional config field to set, can provide multiple times")
 @click.option("--existing-config-action", type=click.Choice(["keep", "overwrite", "discard"]), default="keep", help="Action when config defaults conflict with existing settings")
 @click.option("--interactive/--non-interactive", default=True, help="If not all required settings are provided, use an interactive prompt")
 @click.option("--credential-process/--no-credential-process", default=None, help="Force enable/disable setting the credential process SDK helper")
@@ -181,7 +182,7 @@ def configure_profile(
         return
 
     try:
-        result = subprocess.run(["aws", "--version"], capture_output=True)
+        result = subprocess.run(["aws", "--version"], stdout=subprocess.PIPE, stderr=subprocess.PIPE)
         cli_version = parse_cli_version(result.stdout.decode("utf-8"))
         if cli_version.startswith("1."):
             LOGGER.warn(textwrap.dedent(f"""\
