@@ -4,7 +4,7 @@
 # may not use this file except in compliance with the License. A copy of
 # the License is located at
 #
-# http://aws.amazon.com/apache2.0/
+# http://www.apache.org/licenses/LICENSE-2.0
 #
 # or in the "license" file accompanying this file. This file is
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
@@ -22,7 +22,6 @@ import shlex
 from collections import namedtuple
 
 import botocore
-from botocore.session import Session
 from botocore.exceptions import ClientError, ProfileNotFound
 from botocore.compat import compat_shell_split as shell_split
 
@@ -51,19 +50,26 @@ LOGGER = logging.getLogger(__name__)
 ConfigParams = namedtuple("ConfigParams", ["profile_name", "account_name", "account_id", "role_name", "region"])
 
 def get_short_region(region):
-    area, direction, num = region.split("-")
-    dir_abbr = {
-        "north": "no",
-        "northeast": "ne",
-        "east": "ea",
-        "southeast": "se",
-        "south": "so",
-        "southwest": "sw",
-        "west": "we",
-        "northwest": "nw",
-        "central": "ce",
-    }
-    return "".join([area, dir_abbr.get(direction, direction), num])
+    try:
+        area, direction, num = region.rsplit("-", 2)
+        area_abbr = {
+            "us-gov": "gov"
+        }
+        dir_abbr = {
+            "north": "no",
+            "northeast": "ne",
+            "east": "ea",
+            "southeast": "se",
+            "south": "so",
+            "southwest": "sw",
+            "west": "we",
+            "northwest": "nw",
+            "central": "ce",
+        }
+        return "".join([area_abbr.get(area, area), dir_abbr.get(direction, direction), num])
+    except Exception as e:
+        LOGGER.debug(f"Error creating short region: {e}", exc_info=True)
+        return region
 
 KNOWN_COMPONENTS = [
     "account_name",
@@ -150,28 +156,54 @@ def get_trim_formatter(account_name_patterns, role_name_patterns, formatter):
         return formatter(i, n, **kwargs)
     return trim_formatter
 
+def get_name_case_formatter(account_name_transform, role_name_transform, formatter):
+    field_transform_map = {
+        "account_name": account_name_transform,
+        "role_name": role_name_transform,
+    }
+    def case_formatter(i, n, **kwargs):
+        for field, transform in field_transform_map.items():
+            if not transform:
+                continue
+            if transform == "capitalize":
+                kwargs[field] = kwargs[field].capitalize()
+            elif transform == "casefold":
+                kwargs[field] = kwargs[field].casefold()
+            elif transform == "lower":
+                kwargs[field] = kwargs[field].lower()
+            elif transform == "title":
+                kwargs[field] = kwargs[field].title()
+            elif transform == "upper":
+                kwargs[field] = kwargs[field].upper()
+            else:
+                raise ValueError("Unknown {} transform value {}".format(field, transform))
+        return formatter(i, n, **kwargs)
+    return case_formatter
+
 def get_safe_account_name(name):
     return re.sub(r"[\s\[\]]+", "-", name).strip("-")
 
 @click.command("populate")
 @click.option("--sso-start-url", "-u", metavar="URL", help="Your AWS SSO start URL")
-@click.option("--sso-region", help="The AWS region your AWS SSO instance is deployed in")
+@click.option("--sso-region", metavar="REGION", help="The AWS region your AWS SSO instance is deployed in")
 
-@click.option("--region", "-r", "regions", multiple=True, metavar="REGION", help="AWS region for the profiles, can provide multiple times")
+@click.option("--region", "-r", "regions", metavar="REGION", multiple=True, help="AWS region for the profiles, can provide multiple times")
 
 @click.option("--dry-run", is_flag=True, help="Print the config to stdout instead of writing to your config file")
 
-@click.option("--config-default", "-c", multiple=True, metavar="KEY=VALUE", help="Additional config field to set, can provide multiple times")
+@click.option("--config-default", "-c", metavar="KEY=VALUE", multiple=True, help="Additional config field to set, can provide multiple times")
 @click.option("--existing-config-action", type=click.Choice(["keep", "overwrite", "discard"]), default="keep", help="Action when config defaults conflict with existing settings")
 
-@click.option("--components", "profile_name_components", metavar="VALUE,VALUE,...", default="account_name,role_name,default_style_region", help="Profile name components to join (comma-separated)")
+@click.option("--components", "profile_name_components", metavar="VALUE,VALUE,...", default="account_name,role_name,default_style_region", help=f"Profile name components to join (comma-separated). Possible values are: {' '.join(KNOWN_COMPONENTS)}")
 @click.option("--separator", "--sep", "profile_name_separator", metavar="SEP", help=f"Separator for profile name components, default is '{DEFAULT_SEPARATOR}'")
 @click.option("--include-region", "profile_name_include_region", type=click.Choice(["default", "always"]), default="default", help="By default, the first region is left off the profile name")
 @click.option("--region-style", "profile_name_region_style", type=click.Choice(["short", "long"]), default="short", help="Default is five character region abbreviations")
-@click.option("--trim-account-name", "profile_name_trim_account_name_patterns", multiple=True, default=[], help="Regex to remove from account names, can provide multiple times")
-@click.option("--trim-role-name", "profile_name_trim_role_name_patterns", multiple=True, default=[], help="Regex to remove from role names, can provide multiple times")
-@click.option("--profile-name-process")
-@click.option("--safe-account-names/--raw-account-names", default=True, help="In profiles, replace any character sequences not in A-Za-z0-9-._ with a single -")
+@click.option("--trim-account-name", "profile_name_trim_account_name_patterns", metavar="REGEX", multiple=True, default=[], help="Regex to remove from account names, can provide multiple times")
+@click.option("--trim-role-name", "profile_name_trim_role_name_patterns", metavar="REGEX", multiple=True, default=[], help="Regex to remove from role names, can provide multiple times")
+@click.option("--account-name-case", "profile_name_account_name_case_transform", type=click.Choice(["capitalize", "casefold", "lower", "title", "upper"]), help="Method to change the case of the account name")
+@click.option("--role-name-case", "profile_name_role_name_case_transform", type=click.Choice(["capitalize", "casefold", "lower", "title", "upper"]), help="Method to change the case of the role name")
+@click.option("--profile-name-process", metavar="COMMAND")
+@click.option("--safe-account-names/--raw-account-names", default=True, help="In profiles, replace any character sequences in account names not in A-Za-z0-9-._ with a single -")
 
 @click.option("--credential-process/--no-credential-process", default=None, help="Force enable/disable setting the credential process SDK helper")
 
@@ -190,6 +222,8 @@ def populate_profiles(
         profile_name_region_style,
         profile_name_trim_account_name_patterns,
         profile_name_trim_role_name_patterns,
+        profile_name_account_name_case_transform,
+        profile_name_role_name_case_transform,
         profile_name_process,
         safe_account_names,
         credential_process,
@@ -245,13 +279,18 @@ def populate_profiles(
         profile_name_formatter = get_formatter(profile_name_include_region, region_format, no_region_format)
         if profile_name_trim_account_name_patterns or profile_name_trim_role_name_patterns:
             profile_name_formatter = get_trim_formatter(profile_name_trim_account_name_patterns, profile_name_trim_role_name_patterns, profile_name_formatter)
+        if profile_name_account_name_case_transform or profile_name_role_name_case_transform:
+            profile_name_formatter = get_name_case_formatter(profile_name_account_name_case_transform, profile_name_role_name_case_transform, profile_name_formatter)
 
     try:
         profile_name_formatter(0, 1, account_name="foo", account_id="bar", role_name="baz", region="us-east-1")
     except Exception as e:
         raise click.UsageError("Invalid profile name format: {}".format(e))
 
-    session = Session()
+    session = botocore.session.Session(session_vars={
+        'profile': (None, None, None, None),
+        'region': (None, None, None, None),
+    })
 
     token_fetcher = get_token_fetcher(session,
             instance.region,
@@ -356,7 +395,7 @@ def populate_profiles(
         existing_config = {}
         if existing_config_action != "discard":
             try:
-                existing_config = Session(profile=config.profile_name).get_scoped_config()
+                existing_config = botocore.session.Session(profile=config.profile_name).get_scoped_config()
                 config_values.update(existing_config)
                 existing_profile = True
             except ProfileNotFound:
