@@ -4,7 +4,7 @@
 # may not use this file except in compliance with the License. A copy of
 # the License is located at
 #
-# http://aws.amazon.com/apache2.0/
+# http://www.apache.org/licenses/LICENSE-2.0
 #
 # or in the "license" file accompanying this file. This file is
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
@@ -13,9 +13,14 @@
 
 import logging
 import logging.handlers
+import sys
 
 from aws_sso_lib.config import find_instances, SSOInstance
 
+class StdoutFilter(logging.Filter):
+    def filter(self, rec):
+        return rec.levelno < logging.WARNING
+
 def configure_logging(logger, verbose, **config_args):
     if verbose in [False, None]:
         verbose = 0
@@ -29,9 +34,18 @@ def configure_logging(logger, verbose, **config_args):
     root_logger = logging.getLogger()
 
     if verbose == 0:
-        handler = logging.StreamHandler()
-        handler.setFormatter(logging.Formatter("%(message)s"))
-        logger.addHandler(handler)
+        stdout_handler = logging.StreamHandler(stream=sys.stdout)
+        stdout_handler.setFormatter(logging.Formatter("%(message)s"))
+        stdout_handler.setLevel(logging.DEBUG)
+        stdout_handler.addFilter(StdoutFilter())
+
+        stderr_handler = logging.StreamHandler(stream=sys.stderr)
+        stderr_handler.setFormatter(logging.Formatter("%(message)s"))
+        stderr_handler.setLevel(logging.WARNING)
+
+        logger.addHandler(stdout_handler)
+        logger.addHandler(stderr_handler)
+
         logger.propagate = False
         logger.setLevel(logging.INFO)
     elif verbose == 1:
@@ -78,7 +92,7 @@ def get_instance(sso_start_url, sso_region, sso_start_url_vars=None, sso_region_
             raise GetInstanceError("No AWS SSO instance found")
 
     if len(instances) > 1:
-        raise GetInstanceError(f"Found {len(instances)} SSO instance, please specify one: {SSOInstance.to_strs(instances)}")
+        raise GetInstanceError(f"Found {len(instances)} SSO instances, please specify one: {SSOInstance.to_strs(instances)}")
 
     return instances[0]
 
